from .circle import circle_area, circle_perimeter
from .triangle import triangle_area, triangle_perimeter
from .square import square_area, square_perimeter

__all__ = ["circle_area", "circle_perimeter",
           "triangle_area", "triangle_perimeter",
           "square_area", "square_perimeter"
           ]
